@@ -5,9 +5,10 @@ use strict;
 use warnings;
 use Carp;
 
+use Tie::Array;
 require DynaLoader;
 
-our @ISA = qw(DynaLoader);
+our @ISA = qw(Tie::Array DynaLoader);
 
 # Preloaded methods go here.
 
@@ -15,7 +16,7 @@ our @ISA = qw(DynaLoader);
 sub CLONE_SKIP { 1 }
 
 use overload '='  => sub { $_[0]->clone() },
-             'fallback' => 1;
+	     'fallback' => 1;
 
 sub new() {
   my $class = shift;
@@ -36,4 +37,17 @@ sub new() {
   return $mset;
 }
 
+sub items {
+  my $self = shift;
+  my @array;
+  tie( @array, 'Search::Xapian::ESet', $self );
+  return @array;
+}
+
+sub TIEARRAY {
+  my $class = shift;
+  my $eset = shift;
+  return bless $eset, $class;
+}
+
 1;
