@@ -1,5 +1,9 @@
 package Search::Xapian::Stem;
 
+use 5.006;
+use strict;
+use warnings;
+
 # In a new thread, copy objects of this class to unblessed, undef values.
 sub CLONE_SKIP { 1 }
 
@@ -24,7 +28,7 @@ Search::Xapian::Stem - Snowball stemmer
 
 =item new <language>
 
-Constructor. Takes the language to stem as as parameter.
+Constructor. Takes the language to stem as a parameter.
 
 =item stem_word <word>
 
